@@ -14,7 +14,7 @@ use Params::Validate qw( :all );
 use Readonly;
 use URI;
 
-use version; our $VERSION = qv('0.1.1');
+use version; our $VERSION = qv('0.1.2');
 
 # Module implementation here
 
@@ -260,6 +260,25 @@ sub receipt {
     return $self->_apicall( 'receipts', @_ );
 }
 
+# ok, add some backwards compatibility
+before 'push' => sub {
+    carp( "The 'push' method is deprecated in WebService::Pushover v0.1.0, and will be removed in a future release.  Please use the 'message' method instead." );
+};
+
+sub push {
+    my $self = shift;
+    $self->message( @_ );
+}
+
+before 'tokens' => sub {
+    carp( "The 'tokens' method is deprecated in WebService::Pushover v0.1.0, and will be removed in a future release.  Please use the 'user' method instead." );
+};
+
+sub tokens {
+    my $self = shift;
+    $self->user( @_ );
+}
+
 1; # Magic true value required at end of module
 __END__
 
@@ -270,7 +289,7 @@ WebService::Pushover - interface to Pushover API
 
 =head1 VERSION
 
-This document describes WebService::Pushover version 0.1.1.
+This document describes WebService::Pushover version 0.1.2.
 
 
 =head1 SYNOPSIS
@@ -374,6 +393,10 @@ documentation for valid values.
 
 =back
 
+=item push(I<%params>)
+
+I<push()> is a B<DEPRECATED> alias for I<message()>.  It will be removed in a future release, but remains for backwards compatibility.
+
 =item user(I<%params>)
 
 I<user()> sends an application token and a user token to Pushover and
@@ -397,6 +420,10 @@ registered to the user token.
 
 =back
 
+=item tokens(I<%params>)
+
+I<tokens()> is a B<DEPRECATED> alias for I<user()>.  It will be removed in a future release, but remains for backwards compatibility.
+
 =item receipt(I<%params>)
 
 I<receipt()> sends an application token and a receipt token to Pushover and
@@ -435,6 +462,8 @@ parsed from the JSON or XML response returned by the Pushover API.
 
 =item L<Net::HTTP::Spore>
 
+=item L<Net::HTTP::Spore::Middleware::Header>
+
 =item L<Params::Validate>
 
 =item L<Readonly>
